pub struct AnnotationFillArea<'m, 's> { /* private fields */ }Expand description
A bounded fill region made from one outer and optional inner curves.
Implementations
Sourceimpl<'m, 's> AnnotationFillArea<'m, 's>
impl<'m, 's> AnnotationFillArea<'m, 's>
Sourcepub fn outer_boundary(&self) -> StyleResult<EntityId>
pub fn outer_boundary(&self) -> StyleResult<EntityId>
The OuterBoundary reference to the enclosing IfcCurve. Mandatory.
Sourcepub fn inner_boundaries(&self) -> StyleResult<Vec<EntityId>>
pub fn inner_boundaries(&self) -> StyleResult<Vec<EntityId>>
The InnerBoundaries references to IfcCurves cut out of the fill area, if any.